@@ -17,6 +17,9 @@ my %FACE_MAP = qw(
     12  调皮
     13  呲牙
     14  微笑
+    33  玫瑰
+    34  凋谢
+    36  爱心
     46  强  
     50  难过
     51  酷  
@@ -26,7 +29,7 @@ my %FACE_MAP = qw(
     56  流汗
     57  憨笑
     58  大兵
-    59  
+    72  便便
     73  偷笑
     74  可爱
     75  白眼
@@ -40,6 +43,7 @@ my %FACE_MAP = qw(
     83  晕
     84  折磨
     85  衰
+    87  敲打
     96  冷汗
     118 抱拳
     
